==> messaging-5.16.1-sources.jar: com/liveperson/messaging/model/AmsConnectionAnalytics.java <==
package com.liveperson.messaging.model;

import com.liveperson.infra.log.FlowTags;
import com.liveperson.infra.log.LPLog;

/**
 * Created by shiranr on 6/11/17.
 */

public class AmsConnectionAnalytics {

    private static final String TAG = "AmsConnectionAnalytics";

    private static long mStartConnectingTime = 0;
    private static long mLastConnectingTime = 0;

	private static long mCsdsTaskStart = 0;
	private static long mCsdsTaskEnd = 0;
	private static long mLptagTaskStart = 0;
	private static long mLptagTaskEnd = 0;
	private static long mConfigurationFetcherTaskStart = 0;
	private static long mConfigurationFetcherTaskEnd = 0;
	private static long mSiteSettingsFetcherTaskStart = 0;
	private static long mSiteSettingsFetcherTaskEnd = 0;
	private static long mIdpTaskStart = 0;
	private static long mIdpTaskEnd = 0;
	private static long mRemoveOlderImagesTaskStart = 0;
	private static long mRemoveOlderImagesTaskEnd = 0;
	private static long mCollectSDKConfigurationDataTaskStart = 0;
	private static long mCollectSDKConfigurationDataTaskEnd = 0;
	private static long mDataBaseTaskStart = 0;
	private static long mDataBaseTaskEnd = 0;
	private static long mOpenSocketTaskStart = 0;
	private static long mOpenSocketTaskEnd = 0;
	private static long mCloseConnectionTaskStart = 0;
	private static long mCloseConnectionTaskEnd = 0;
	private static long mConcurrentTasksStart = 0;
	private static long mConcurrentTasksEnd = 0;

    public static void startConnecting() {
        mStartConnectingTime = System.currentTimeMillis();
    }
	public static void startDisconnecting() {
		if (mStartConnectingTime > 0){
			LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "Disconnecting. tried to connect for " + (mStartConnectingTime -  System.currentTimeMillis()) + " millis");
			mStartConnectingTime = 0;
		}else{
			LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "Disconnecting. was connected for " + (System.currentTimeMillis() - mLastConnectingTime) + " millis");
			mLastConnectingTime = 0;
		}
	}

    public static void connected() {
		mLastConnectingTime = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "Connection time overall = " + (mLastConnectingTime - mStartConnectingTime) + " millis");
		mStartConnectingTime = 0;
	}

	public static void csdsTaskStart() {
		mCsdsTaskStart = System.currentTimeMillis();
	}

	public static void csdsTaskEnd() {
		mCsdsTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "CsdsTask: task time = " + (mCsdsTaskEnd - mCsdsTaskStart) + " millis");
	}

	public static void lptagTaskStart() {
		mLptagTaskStart = System.currentTimeMillis();
	}

	public static void lptagTaskEnd() {
		mLptagTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "LptagTask: task time = " + (mLptagTaskEnd - mLptagTaskStart) + " millis");
	}

	public static void configurationFetcherTaskStart() {
		mConfigurationFetcherTaskStart = System.currentTimeMillis();
	}

	public static void configurationFetcherTaskEnd() {
		mConfigurationFetcherTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "ConfigurationFetcherTask: task time = " + (mConfigurationFetcherTaskEnd - mConfigurationFetcherTaskStart) + " millis");
	}

	public static void siteSettingsFetcherTaskStart() {
		mSiteSettingsFetcherTaskStart = System.currentTimeMillis();
	}

	public static void siteSettingsFetcherTaskEnd() {
		mSiteSettingsFetcherTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "SiteSettingsFetcherTask: task time = " + (mSiteSettingsFetcherTaskEnd - mSiteSettingsFetcherTaskStart) + " millis");
	}

	public static void idpTaskStart() {
		mIdpTaskStart = System.currentTimeMillis();
	}

	public static void idpTaskEnd() {
		mIdpTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "IdpTask: task time = " + (mIdpTaskEnd - mIdpTaskStart) + " millis");
	}

	public static void removeOlderImagesTaskStart() {
		mRemoveOlderImagesTaskStart = System.currentTimeMillis();
	}

	public static void removeOlderImagesTaskEnd() {
		mRemoveOlderImagesTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "RemoveOlderImagesTask: task time = " + (mRemoveOlderImagesTaskEnd - mRemoveOlderImagesTaskStart) + " millis");
	}

	public static void databaseTaskStart() {
		mDataBaseTaskStart = System.currentTimeMillis();
	}

	public static void databaseTaskEnd() {
		mDataBaseTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "DataBaseTask: task time = " + (mDataBaseTaskEnd - mDataBaseTaskStart) + " millis");
	}
	public static void collectSDKConfigurationDataTaskStart() {
		mCollectSDKConfigurationDataTaskStart = System.currentTimeMillis();
	}

	public static void collectSDKConfigurationDataTaskEnd() {
		mCollectSDKConfigurationDataTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "CollectSDKConfigurationDataTask: task time = " + (mCollectSDKConfigurationDataTaskEnd - mCollectSDKConfigurationDataTaskStart) + " millis");
	}

	public static void openSocketTaskStart() {
		mOpenSocketTaskStart = System.currentTimeMillis();
	}

	public static void openSocketTaskEnd() {
		mOpenSocketTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "OpenSocketTask: task time = " + (mOpenSocketTaskEnd - mOpenSocketTaskStart) + " millis");
	}

	public static void concurrentTasksStart() {
		mConcurrentTasksStart = System.currentTimeMillis();
	}

	public static void concurrentTasksEnd() {
		mConcurrentTasksEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "ConcurrentTasks: task time = " + (mConcurrentTasksEnd - mConcurrentTasksStart) + " millis");
	}

	public static void socketReady() {
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "OpenSocketTask: socket ready! time since socket opened: " + (System.currentTimeMillis() - mOpenSocketTaskEnd) );
	}

	public static void closeConnectionTaskStart() {
		mCloseConnectionTaskStart = System.currentTimeMillis();
	}

	public static void closeConnectionTaskEnd() {
		mCloseConnectionTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "CloseConnectionTask: task time = " + (mCloseConnectionTaskEnd - mCloseConnectionTaskStart) + " millis");
	}


}

==> messaging-5.23.1-sources.jar: com/liveperson/messaging/model/AmsConnectionAnalytics.java <==
package com.liveperson.messaging.model;

import com.liveperson.infra.log.FlowTags;
import com.liveperson.infra.log.LPLog;

/**
 * Created by shiranr on 6/11/17.
 */

public class AmsConnectionAnalytics {

    private static final String TAG = "AmsConnectionAnalytics";

    private static long mStartConnectingTime = 0;
    private static long mLastConnectingTime = 0;

	private static long mCsdsTaskStart = 0;
	private static long mCsdsTaskEnd = 0;
	private static long mLptagTaskStart = 0;
	private static long mLptagTaskEnd = 0;
	private static long mConfigurationFetcherTaskStart = 0;
	private static long mConfigurationFetcherTaskEnd = 0;
	private static long mSiteSettingsFetcherTaskStart = 0;
	private static long mSiteSettingsFetcherTaskEnd = 0;
	private static long mIdpTaskStart = 0;
	private static long mIdpTaskEnd = 0;
	private static long mRemoveOlderImagesTaskStart = 0;
	private static long mRemoveOlderImagesTaskEnd = 0;
	private static long mCollectSDKConfigurationDataTaskStart = 0;
	private static long mCollectSDKConfigurationDataTaskEnd = 0;
	private static long mDataBaseTaskStart = 0;
	private static long mDataBaseTaskEnd = 0;
	private static long mOpenSocketTaskStart = 0;
	private static long mOpenSocketTaskEnd = 0;
	private static long mCloseConnectionTaskStart = 0;
	private static long mCloseConnectionTaskEnd = 0;
	private static long mConcurrentTasksStart = 0;
	private static long mConcurrentTasksEnd = 0;
	private static long mGetActiveConversationTaskStart = 0;
	private static long mGetActiveConversationTaskEnd = 0;

    public static void startConnecting() {
        mStartConnectingTime = System.currentTimeMillis();
    }
	public static void startDisconnecting() {
		if (mStartConnectingTime > 0){
			LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "Disconnecting. tried to connect for " + (mStartConnectingTime -  System.currentTimeMillis()) + " millis");
			mStartConnectingTime = 0;
		}else{
			LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "Disconnecting. was connected for " + (System.currentTimeMillis() - mLastConnectingTime) + " millis");
			mLastConnectingTime = 0;
		}
	}

    public static void connected() {
		mLastConnectingTime = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "Connection time overall = " + (mLastConnectingTime - mStartConnectingTime) + " millis");
		mStartConnectingTime = 0;
	}

	public static void getActiveConversationTaskStart() {
		mGetActiveConversationTaskStart = System.currentTimeMillis();
	}

	public static void getActiveConversationTaskEnd() {
		mGetActiveConversationTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "getActiveConversationTask: task time = " + (mGetActiveConversationTaskEnd - mGetActiveConversationTaskStart) + " millis");
	}

	public static void csdsTaskStart() {
		mCsdsTaskStart = System.currentTimeMillis();
	}

	public static void csdsTaskEnd() {
		mCsdsTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "CsdsTask: task time = " + (mCsdsTaskEnd - mCsdsTaskStart) + " millis");
	}

	public static void lptagTaskStart() {
		mLptagTaskStart = System.currentTimeMillis();
	}

	public static void lptagTaskEnd() {
		mLptagTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "LptagTask: task time = " + (mLptagTaskEnd - mLptagTaskStart) + " millis");
	}

	public static void configurationFetcherTaskStart() {
		mConfigurationFetcherTaskStart = System.currentTimeMillis();
	}

	public static void configurationFetcherTaskEnd() {
		mConfigurationFetcherTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "ConfigurationFetcherTask: task time = " + (mConfigurationFetcherTaskEnd - mConfigurationFetcherTaskStart) + " millis");
	}

	public static void siteSettingsFetcherTaskStart() {
		mSiteSettingsFetcherTaskStart = System.currentTimeMillis();
	}

	public static void siteSettingsFetcherTaskEnd() {
		mSiteSettingsFetcherTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "SiteSettingsFetcherTask: task time = " + (mSiteSettingsFetcherTaskEnd - mSiteSettingsFetcherTaskStart) + " millis");
	}

	public static void idpTaskStart() {
		mIdpTaskStart = System.currentTimeMillis();
	}

	public static void idpTaskEnd() {
		mIdpTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "IdpTask: task time = " + (mIdpTaskEnd - mIdpTaskStart) + " millis");
	}

	public static void removeOlderImagesTaskStart() {
		mRemoveOlderImagesTaskStart = System.currentTimeMillis();
	}

	public static void removeOlderImagesTaskEnd() {
		mRemoveOlderImagesTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "RemoveOlderImagesTask: task time = " + (mRemoveOlderImagesTaskEnd - mRemoveOlderImagesTaskStart) + " millis");
	}

	public static void databaseTaskStart() {
		mDataBaseTaskStart = System.currentTimeMillis();
	}

	public static void databaseTaskEnd() {
		mDataBaseTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "DataBaseTask: task time = " + (mDataBaseTaskEnd - mDataBaseTaskStart) + " millis");
	}
	public static void collectSDKConfigurationDataTaskStart() {
		mCollectSDKConfigurationDataTaskStart = System.currentTimeMillis();
	}

	public static void collectSDKConfigurationDataTaskEnd() {
		mCollectSDKConfigurationDataTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "CollectSDKConfigurationDataTask: task time = " + (mCollectSDKConfigurationDataTaskEnd - mCollectSDKConfigurationDataTaskStart) + " millis");
	}

	public static void openSocketTaskStart() {
		mOpenSocketTaskStart = System.currentTimeMillis();
	}

	public static void openSocketTaskEnd() {
		mOpenSocketTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "OpenSocketTask: task time = " + (mOpenSocketTaskEnd - mOpenSocketTaskStart) + " millis");
	}

	public static void concurrentTasksStart() {
		mConcurrentTasksStart = System.currentTimeMillis();
	}

	public static void concurrentTasksEnd() {
		mConcurrentTasksEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "ConcurrentTasks: task time = " + (mConcurrentTasksEnd - mConcurrentTasksStart) + " millis");
	}

	public static void socketReady() {
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "OpenSocketTask: socket ready! time since socket opened: " + (System.currentTimeMillis() - mOpenSocketTaskEnd) );
	}

	public static void closeConnectionTaskStart() {
		mCloseConnectionTaskStart = System.currentTimeMillis();
	}

	public static void closeConnectionTaskEnd() {
		mCloseConnectionTaskEnd = System.currentTimeMillis();
		LPLog.INSTANCE.d(TAG, FlowTags.LOGIN, "CloseConnectionTask: task time = " + (mCloseConnectionTaskEnd - mCloseConnectionTaskStart) + " millis");
	}


}
